TemplateWrapper

Struct TemplateWrapper 

pub struct TemplateWrapper<T: TemplateSimple> { /* private fields */ }
Wrapper struct for TemplateSimple that allows us to have custom error messages and a better api for using the web frameworks

Implementations

Source

impl<T: TemplateSimple> TemplateWrapper<T>

pub fn from(template: T) -> Self

Create an AxumTemplate from a TemplateSimple struct

pub fn with_custom_error_message(self, message: String) -> Self

Specify a custom error message to be rendered when template.render_once() returns an RenderError